# File: GetSysInfo.ps1
# Syntax: GetSysInfo

#----------------------------------------------------------
# Helper function
#----------------------------------------------------------

function WriteInfo ($description, $value)
{
    "{0,-20} : {1}" -f $description, $value
}

#--- script main -------------------------------------------

[int]$REMOVABLE_DISK = 2
[int]$LOCAL_DISK     = 3

# Collect information
$computerSystem  = get-wmiobject win32_ComputerSystem
$operatingSystem = get-wmiobject win32_OperatingSystem
$processor       = Get-WmiObject win32_processor
$disks           = get-wmiobject win32_logicaldisk

# Write information to stdout
""
"COMPUTER SYSTEM"
""
WriteInfo "HostName"         $computerSystem.Name
WriteInfo "Owner"            $computerSystem.PrimaryOwnerName
WriteInfo "Domain"           $computerSystem.Domain
WriteInfo "Manufacturer"     $computerSystem.Manufacturer
WriteInfo "Model"            $computerSystem.Model
WriteInfo "OS name"          $operatingSystem.Caption
WriteInfo "OS Service Pack"  $operatingSystem.ServicePackMajorVersion
WriteInfo "OS version"       $operatingSystem.Version
WriteInfo "OS serial number" $operatingSystem.SerialNumber
WriteInfo "OS directory"     $operatingSystem.SystemDirectory
""

""
"PROCESSOR and MEMORY"
""
WriteInfo "Class"            $processor.CreationClassName
WriteInfo "Manufacturer"     $processor.Manufacturer
WriteInfo "Name"             $processor.Name.Trim(' ')
WriteInfo "Description"      $processor.Description
WriteInfo "Number of cores"  $processor.NumberOfCores
WriteInfo "L2 cache size"    ("{0:#.#} MB" -f ($processor.L2CacheSize/ 1024.)) # L2CacheSize is in KB
WriteInfo "Max clock speed"  ("{0} MHz" -f $processor.MaxClockSpeed)
WriteInfo "Physical memory"  ("{0:#.#} GB" -f ($computerSystem.TotalPhysicalMemory / (1024*1024*1024)))
""

""
"DISK SPACE"
""
$format = "{0,-6} {1,-10} {2,-10} {3,7} {4,10} {5,10} {6,7}"
$format -f "Drive", "DiskType", "VolumeName", "Free", "FreeSpace", "TotalSize", "Format"
""
foreach($disk in $disks)
{
    if (($disk.DriveType -eq $REMOVABLE_DISK) -or ($disk.DriveType -eq $LOCAL_DISK))
    {
       if ($disk.DriveType -eq $REMOVABLE_DISK)
       {
           $driveType =  "removable"
       }
       else           
       {
           $driveType =  "local"
       }

       $driveLetter = $disk.DeviceId.Substring(0,1)
       $driveInfo = [System.IO.DriveInfo]($driveLetter)
       $format -f $disk.DeviceId, $driveType, $disk.VolumeName`
          , ("{0:P1}" -f ($disk.FreeSpace / $disk.Size))`
          , ("{0:N2} GB" -f ($disk.FreeSpace / (1024*1024*1024)))`
          , ("{0:N2} GB" -f ($disk.Size / (1024*1024*1024)))`
          , $driveInfo.DriveFormat
    }
}
""


